@@ -22,7 +22,7 @@ class DeviceType(Enum):
     Thermostat = ApiDeviceType.THERMOSTAT, "Thermostat"
     LockGroup = ApiDeviceType.LOCK_GROUP, "Lock Group"
     TimedSwitch = ApiDeviceType.TIMED_SWITCH, "Timed Switch"
-    SOMFY = ApiDeviceType.SOMFY, "Somfy"
+    Somfy = ApiDeviceType.SOMFY, "Somfy"
     IrDevice = ApiDeviceType.IR_DEVICE, "Infra Red Device"
     RollingScenario = ApiDeviceType.ROLLING_SCENARIO, "Rolling Scenario"
 
@@ -290,3 +290,13 @@ class SwitchBeeTwoWay(SwitchBeeBaseSwitch, SwitchBeeBaseDevice):
         if self.type != DeviceType.TwoWay:
             raise ValueError("only Two Way are allowed")
         super().__post_init__()
+
+
+@final
+@dataclass
+class SwitchBeeSomfy(SwitchBeeBaseDevice):
+    def __post_init__(self) -> None:
+        """Post initialization validate device type category as Scenario."""
+        if self.type != DeviceType.Somfy:
+            raise ValueError("only Scenario are allowed")
+        super().__post_init__()
